resolve_variables

Function resolve_variables 

pub fn resolve_variables(
    deps: &mut [GradleDependency],
    properties: &HashMap<String, String>,
)
Resolves $var and ${var} references in dependency versions using the given properties map.

If a version is a variable reference and the variable is found in properties, the version is replaced with the resolved value. The version_range is kept as-is (pointing to the variable reference in source).